Description Usage Details Value Examples
View source: R/figtabeqaddin.R
Invoke RStudio add-in to help insert either figure, table or equation references
1 |
It is assummed that this addin will be called whilst the focus of RStudio is an R markdown document that will allow users to insert references - for example a Bookdown document.
It will search the R markdown document and collect all chunk names and equation references. The user can then choose what to insert.
When the user has chosen what to insert, they should click Done. The reference, including required syntax will be inserted at the cursor position.
Inserts selected figure, table or equation reference at current location.
1 2 3 4 | ## Not run:
insert_figtabeqref()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.